import PLVLogger from '../modules/log/PLVLogger';
const TAG = '[PLVLazyDataSource]';
class j1 {
    constructor() {
        this.l1 = [];
    }
    totalCount() {
        return 0;
    }
    getData(index) {
        return undefined;
    }
    registerDataChangeListener(listener) {
        if (this.l1.indexOf(listener) < 0) {
            PLVLogger.info(TAG, 'registerDataChangeListener');
            this.l1.push(listener);
        }
    }
    unregisterDataChangeListener(listener) {
        const pos = this.l1.indexOf(listener);
        if (pos >= 0) {
            PLVLogger.info(TAG, 'unregisterDataChangeListener');
            this.l1.splice(pos, 1);
        }
    }
    m1() {
        this.l1.forEach(listener => {
            listener.onDataReloaded();
        });
    }
    n1(index) {
        this.l1.forEach(listener => {
            listener.onDataAdd(index);
        });
    }
    o1(index) {
        this.l1.forEach(listener => {
            listener.onDataChange(index);
        });
    }
    q1(index) {
        this.l1.forEach(listener => {
            listener.onDataDelete(index);
        });
    }
    s1(from, to) {
        this.l1.forEach(listener => {
            listener.onDataMove(from, to);
        });
    }
    t1(dataOperations) {
        this.l1.forEach(listener => {
            listener.onDatasetChange(dataOperations);
        });
    }
}
export default class PLVLazyDataSource extends j1 {
    constructor() {
        super(...arguments);
        this.dataArray = [];
    }
    bindSource(source) {
        source._bindSource = this;
        this._beBindSource = source;
        this.dataArray = source.dataArray;
    }
    unbindSource() {
        if (this._beBindSource) {
            this._beBindSource._bindSource = undefined;
        }
    }
    totalCount() {
        return this.dataArray.length;
    }
    getData(index) {
        return this.dataArray[index];
    }
    addData(index, ...data) {
        if (data.length === 0) {
            return;
        }
        this.dataArray.splice(index, 0, ...data);
        const operation = [{
                type: DataOperationType.ADD,
                index: index,
                count: data.length
            }];
        if (this._bindSource) {
            this._bindSource.t1(operation);
        }
        else {
            this.t1(operation);
        }
    }
    pushData(...data) {
        if (data.length === 0) {
            return;
        }
        const index = this.totalCount();
        this.dataArray.push(...data);
        const operation = [{
                type: DataOperationType.ADD,
                index: index,
                count: data.length
            }];
        if (this._bindSource) {
            this._bindSource.t1(operation);
        }
        else {
            this.t1(operation);
        }
    }
    deleteData(index) {
        this.dataArray.splice(index, 1);
        const operation = [{
                type: DataOperationType.DELETE,
                index: index,
                count: 1
            }];
        if (this._bindSource) {
            this._bindSource.t1(operation);
        }
        else {
            this.t1(operation);
        }
    }
    moveData(from, to) {
        const k1 = this.dataArray[from];
        this.dataArray[from] = this.dataArray[to];
        this.dataArray[to] = k1;
        const operation = [{
                type: DataOperationType.MOVE,
                index: {
                    from: from, to: to
                }
            }];
        if (this._bindSource) {
            this._bindSource.t1(operation);
        }
        else {
            this.t1(operation);
        }
    }
    changeData(index, data) {
        this.dataArray.splice(index, 1, data);
        const operation = [{
                type: DataOperationType.CHANGE,
                index: index
            }];
        if (this._bindSource) {
            this._bindSource.t1(operation);
        }
        else {
            this.t1(operation);
        }
    }
    clearData() {
        this.dataArray.length = 0;
        this.reloadData();
    }
    reloadData() {
        const operation = [{
                type: DataOperationType.RELOAD
            }];
        if (this._bindSource) {
            this._bindSource.t1(operation);
        }
        else {
            this.t1(operation);
        }
    }
}
