import { instanceToPlain, plainToClass, plainToClassFromExist } from 'class-transformer';
export default class PLVJSONUtils {
    static safeStringify(value, replacer) {
        try {
            return JSON.stringify(value || new Object(), replacer);
        }
        catch (e) {
            return '';
        }
    }
    static safeParse(text) {
        try {
            return JSON.parse(text || '');
        }
        catch (e) {
            return undefined;
        }
    }
    static json2Bean(f3, g3) {
        try {
            return plainToClass(f3, JSON.parse(g3), {
                enableImplicitConversion: false, exposeDefaultValues: true
            });
        }
        catch (e) {
            return undefined;
        }
    }
    static bean2Json(data) {
        try {
            if (data == null || data == undefined) {
                return '';
            }
            return JSON.stringify(instanceToPlain(data));
        }
        catch (e) {
            return "";
        }
    }
    static bean2Bean(e3, plain) {
        try {
            return plainToClassFromExist(e3, plain, {
                enableImplicitConversion: false, exposeDefaultValues: true
            });
        }
        catch (e) {
            return undefined;
        }
    }
    static httpData2Bean(d3, plain) {
        try {
            plain.data = plainToClassFromExist(d3, plain.data, {
                enableImplicitConversion: false, exposeDefaultValues: true
            });
            try {
                plain.data.fill();
            }
            catch (err) {
            }
            return plain.data;
        }
        catch (e) {
            return undefined;
        }
    }
    static json2Map(c3) {
        return new Map(Object.entries(JSON.parse(c3)));
    }
    static object2Map(object) {
        return new Map(Object.entries(object));
    }
    static map2json(map) {
        const obj = {};
        map.forEach((value, key) => {
            if (key && value) {
                obj[key] = value;
            }
        });
        return obj;
    }
    static map2jsonStr(map, replacer) {
        return PLVJSONUtils.safeStringify(PLVJSONUtils.map2json(map), replacer);
    }
    static toUnescapedData(a3) {
        if (!a3.includes('\\')) {
            return a3;
        }
        return a3.substring(1, a3.length - 1)
            .replace(/\\"/g, '"')
            .replace(/\\\\/g, '\\');
    }
    static toFillData(v2, w2) {
        let z2 = undefined;
        if (typeof w2 === 'string') {
            z2 = PLVJSONUtils.json2Bean(v2, w2);
        }
        else if (typeof w2 === 'object') {
            z2 = PLVJSONUtils.bean2Bean(v2, w2);
        }
        z2?.fill();
        return z2;
    }
}
