import PLVLogger from '../modules/log/PLVLogger';
const TAG = '[PLVScheduledTask]';
export class PLVScheduledTask {
    constructor(callback, delay, period = delay) {
        this.callback = callback;
        this.delay = delay;
        this.period = period;
        this.timerId = undefined;
        this.nextExecutionTime = 0;
        this.isRunning = false;
    }
    start() {
        if (this.isRunning) {
            return;
        }
        this.isRunning = true;
        this.nextExecutionTime = Date.now() + this.delay;
        this.scheduleNextExecution();
    }
    async scheduleNextExecution() {
        if (!this.isRunning) {
            return;
        }
        const now = Date.now();
        const y3 = Math.max(0, this.nextExecutionTime - now);
        this.timerId = setTimeout(async () => {
            try {
                await this.callback();
            }
            catch (error) {
                PLVLogger.printError(TAG, 'scheduleNextExecution error', error);
            }
            this.nextExecutionTime = Date.now() + this.period;
            this.scheduleNextExecution();
        }, y3);
    }
    cancel() {
        if (!this.isRunning) {
            return;
        }
        clearTimeout(this.timerId);
        this.isRunning = false;
    }
}
