import PLVLogger from '../modules/log/PLVLogger';
import PLVCommonConstants from './PLVCommonConstants';
import { AppUtil, DeviceUtil, PasteboardUtil } from '@pura/harmony-utils';
import ConfigurationConstant from "@ohos.app.ability.ConfigurationConstant";
import window from "@ohos.window";
import scanBarcode from "@hms.core.scan.scanBarcode";
import scanCore from "@hms.core.scan.scanCore";
const TAG = '[PLVUtils]';
export default class PLVUtils {
    constructor() {
    }
    static init(context, windowStage) {
        AppUtil.init(context, windowStage);
    }
    static getClassTag(tag, f6 = true) {
        let key = f6 ? '[Anonymous]' : undefined;
        if (typeof tag == 'string') {
            key = tag;
        }
        else {
            if (tag && tag.constructor) {
                key = `[${tag.constructor.name}]`;
            }
        }
        return key;
    }
    static retryWhen(when, retry) {
        try {
            return Promise.resolve(when());
        }
        catch (err) {
            PLVLogger.printWarn(TAG, 'retryWhen catch error', err);
            try {
                return Promise.resolve(retry());
            }
            catch (err) {
                PLVLogger.printWarn(TAG, 'retryWhen catch error while retry', err);
                return Promise.reject(err);
            }
        }
    }
    static async disposablePromise(promise, e6) {
        try {
            await promise;
        }
        catch (error) {
            return Promise.reject(error);
        }
        if (e6?.isDispose()) {
            return Promise.reject(new Error('error'));
        }
        return promise;
    }
    static safePromise(callback, a6) {
        const promise = new Promise(async (c6, d6) => {
            try {
                await callback(c6, d6);
            }
            catch (err) {
                PLVLogger.printWarn(TAG, 'safePromise catch error', err);
                d6(err);
            }
        });
        return PLVUtils.disposablePromise(promise, a6);
    }
    static async retryPromise(w5, x5, promise, y5) {
        let z5 = 0;
        let error = new Error('error');
        while (z5 <= w5) {
            try {
                const result = await promise;
                if (!y5?.isDispose()) {
                    return result;
                }
            }
            catch (err) {
                error = err;
                PLVLogger.printWarn(TAG, `retryPromise retryCount=${z5} catch error`, err);
            }
            if (++z5 > w5) {
                break;
            }
            if (y5?.isDispose()) {
                return Promise.reject(error);
            }
            await PLVUtils.delay(x5);
        }
        return Promise.reject(error);
    }
    static async delay(delay) {
        return PLVUtils.safePromise((v5) => {
            setTimeout(v5, delay);
        });
    }
    static validCallback(callback) {
        return '/' != callback;
    }
    static getPid() {
        const current = Date.now();
        const random = Math.floor(Math.random() * 1000000) + 1000000;
        return current + "X" + random;
    }
    static getDeviceId() {
        return DeviceUtil.getDeviceId();
    }
    static undefinedToValue(data, callback, delay) {
        setTimeout(() => {
            callback(data);
        }, delay ? delay : PLVCommonConstants.DELAY_TIME_S);
        return undefined;
    }
    static copyText(text) {
        return PasteboardUtil.setDataText(text);
    }
    static changeOrientation(m5, component, n5) {
        let context = getContext(component);
        let o5 = (s5) => {
            s5.setPreferredOrientation(m5 ? window.Orientation.LANDSCAPE : window.Orientation.PORTRAIT);
        };
        n5 ? o5(n5) :
            window.getLastWindow(context).then((r5) => {
                o5(r5);
            });
    }
    static isLandscape(component) {
        let context = getContext(component);
        return context.config.direction === ConfigurationConstant.Direction.DIRECTION_HORIZONTAL;
    }
    static setWindowFullScreen(isLayoutFullScreen = false, isFullScreen = false, component, c5) {
        return new Promise((e5) => {
            let context = getContext(component);
            let f5 = (j5) => {
                let k5 = j5.getWindowProperties().isLayoutFullScreen;
                let l5 = j5.getWindowProperties().isFullScreen;
                j5.setWindowLayoutFullScreen(isLayoutFullScreen);
                if (canIUse("SystemCapability.Window.SessionManager")) {
                    j5.setSpecificSystemBarEnabled('status', !isFullScreen);
                    e5([k5, l5]);
                }
            };
            c5 ? f5(c5) :
                window.getLastWindow(context).then((i5) => {
                    f5(i5);
                });
        });
    }
    static startScan(component) {
        return new Promise((z4) => {
            if (canIUse('SystemCapability.Multimedia.Scan.Core') && canIUse('SystemCapability.Multimedia.Scan.ScanBarcode')) {
                let options = {
                    scanTypes: [scanCore.ScanType.ALL],
                    enableMultiMode: true,
                    enableAlbum: true
                };
                try {
                    scanBarcode.startScanForResult(getContext(component), options).then((result) => {
                        PLVLogger.info(TAG, 'Promise scan result: ' + JSON.stringify(result));
                        z4(result.originalValue);
                    }).catch((error) => {
                        PLVLogger.error(TAG, 'Promise error: ' + JSON.stringify(error));
                    });
                }
                catch (error) {
                    PLVLogger.error(TAG, 'failReason: ' + JSON.stringify(error));
                }
            }
        });
    }
    static getVideoRectJS(w4) {
        let x4 = "function getVideoRect() {";
        {
            x4 += "let tags = document.getElementsByTagName('video');";
            x4 += "if (tags.length > 0) {";
            {
                x4 += "let video = tags[0];";
                x4 += "return {";
                {
                    x4 += "'width': video.videoWidth,";
                    x4 += "'height': video.videoHeight";
                }
                x4 += "};";
            }
            x4 += "}";
            x4 += "return {};";
        }
        x4 += "}";
        x4 += "getVideoRect();";
        return w4 ? PLVCommonConstants.JS_PRE + x4 : x4;
    }
    static getExitFullScreenJS(u4) {
        let v4 = "function exitFullScreen() {";
        v4 += "document.getElementsByTagName('video')[0].webkitExitFullScreen()";
        v4 += "}";
        v4 += "exitFullScreen();";
        return u4 ? PLVCommonConstants.JS_PRE + v4 : v4;
    }
}
