import { PLVTextUtils } from './PLVTextUtils';
import PLVLogger from '../modules/log/PLVLogger';
const TAG = '[PLVWebUtils]';
export class PLVWebUtils {
    static toWebViewContent(content, color) {
        if (!content) {
            return content;
        }
        if (!color) {
            color = "rgba(0, 0, 0, 1)";
        }
        const style = "style=\" width:100%;\"";
        const m6 = "word-break:break-all;";
        const n6 = "color: " + color + ";";
        content = content.replace(/src=\"\/\//g, "src=\"https://");
        content = content.replace(/<img /g, "<img " + style + " ");
        content = content.replace(/<li>/g, "<li style=\"" + n6 + "\">");
        content = content.replace(/<p>/g, "<p style=\"" + m6 + n6 + "\">");
        content = content.replace(/<div>/g, "<div style=\"" + m6 + n6 + "\">");
        content = content.replace(/<table>/g, "<table border='1' rules=all style=\"" + n6 + "\">");
        content = content.replace(/<td>/g, "<td width=\"36\">");
        content = content.replace(/color: (#([0-9a-fA-F]{6}|[0-9a-fA-F]{8}));/g, (p6, q6) => {
            return `color: ${PLVWebUtils.toRGBA(q6)};`;
        });
        content = "<!DOCTYPE html>\n" +
            "<html lang=\"en\">\n" +
            "<head>\n" +
            "        <meta charset=\"UTF-8\">\n" +
            "        <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\n" +
            "        <meta http-equiv=\"X-UA-Compatible\" content=\"ie=edge\">\n" +
            "        <title>Document</title>\n" +
            "</head>\n" +
            "<body style=\" color: " + color + ";margin:0;padding:0\">" +
            content + "</body>\n" +
            "</html>";
        return content;
    }
    static toRGBA(l6) {
        let alpha = 1;
        if (l6.length > 7) {
            alpha = parseInt(l6.substring(1, 3), 16) / 255;
            l6 = `#${l6.substring(3)}`;
        }
        const red = parseInt(l6.substring(1, 3), 16);
        const green = parseInt(l6.substring(3, 5), 16);
        const blue = parseInt(l6.substring(5, 7), 16);
        return `rgba(${red}, ${green}, ${blue}, ${alpha})`;
    }
    static cleanHTML(input) {
        let i6 = input.replace(/<p>((?:<img[^>]*>)+)<\/p>/g, (match, k6) => {
            return k6.replace(/<img[^>]*>/g, '[图片]');
        });
        i6 = i6.replace(/<p><a[^>]*>(.*?)<\/a><\/p>/g, '$1');
        i6 = i6.replace(/<p>(.*?)<\/p>/g, '$1');
        i6 = i6.replace(/\n/g, ' ');
        i6 = PLVTextUtils.convertSpecialString(i6);
        return i6;
    }
    static openWebLink(url, component) {
        let want = {
            action: 'ohos.want.action.viewData',
            entities: ['entity.system.browsable'],
            uri: url
        };
        const context = getContext(component);
        if (context) {
            context.startAbility(want)
                .then(() => {
                PLVLogger.info(TAG, `openWebLink success, url: ${url}`);
            })
                .catch((err) => {
                PLVLogger.error(TAG, `openWebLink error, url: ${url}, code: ${err.code}, message: ${err.message}`);
            });
        }
        else {
            PLVLogger.error(TAG, `openWebLink error, context: undefined`);
        }
    }
}
