import PLVCommonConstants from '../../common/PLVCommonConstants';
import { PLVPrintLogLevel } from '../../common/PLVCommonEnums';
import { DateFileNameGenerator, FileLastModifiedCleanStrategy, FileSizeBackupStrategy, LogConfiguration, OhPrinter, XLog } from '@ohos-port/xlog';
import util from "@ohos.util";
import { PLVXLogBuilder } from './PLVXLogFilePrinter';
export class PLVLogger {
    constructor() {
        this.printLogLevel = PLVPrintLogLevel.ALL;
        this.tag = PLVCommonConstants.TAG.substring(1, PLVCommonConstants.TAG.length - 1);
        this.format = "%s";
    }
    init(context) {
        const config = new LogConfiguration.Builder()
            .setTag(this.tag)
            .build();
        const filesDir = context.filesDir;
        this.filePrinter = new PLVXLogBuilder(`${filesDir}/log`, true, '../../modules/log/PLVXLogWorker.ets')
            .setCleanStrategy(new FileLastModifiedCleanStrategy(5 * 24 * 60 * 60 * 1000))
            .setFileNameGenerator(new DateFileNameGenerator())
            .setBackupStrategy(new FileSizeBackupStrategy(10 * 1024 * 1024))
            .build();
        XLog.init(config, [new OhPrinter()]);
    }
    level(a7) {
        this.printLogLevel = a7;
    }
    debug(tag, message, z6 = true) {
        const msg = util.format(this.format, tag, message);
        this.intercept(PLVPrintLogLevel.DEBUG, msg, z6) || XLog.d(msg);
    }
    info(tag, message, y6 = true) {
        const msg = util.format(this.format, tag, message);
        this.intercept(PLVPrintLogLevel.INFO, msg, y6) || XLog.i(msg);
    }
    warn(tag, message, x6 = true) {
        const msg = util.format(this.format, tag, message);
        this.intercept(PLVPrintLogLevel.WARN, msg, x6) || XLog.w(msg);
    }
    error(tag, message, w6 = true) {
        const msg = util.format(this.format, tag, message);
        this.intercept(PLVPrintLogLevel.ERROR, msg, w6) || XLog.e(msg);
    }
    printWarn(tag, v6, err) {
        const msg = this.generateErrorMsg(v6, err);
        this.warn(tag, msg);
        return msg;
    }
    printError(tag, u6, err) {
        const msg = this.generateErrorMsg(u6, err);
        this.error(tag, msg);
        return msg;
    }
    generateErrorMsg(s6, err) {
        let t6 = '';
        if (err && err.code) {
            t6 = `, code=${err.code}`;
        }
        return `${s6}: name=${err.name}, message=${err.message}${t6}\n${err.stack}`;
    }
    intercept(level, msg, r6 = true) {
        if (r6) {
            this.filePrinter?.println(level, this.tag, msg);
        }
        return this.printLogLevel > level;
    }
}
export default new PLVLogger();
