import { client_socket } from 'socket';
import PLVLogger from '../log/PLVLogger';
const TAG = '[PLVSocketIO]';
export class PLVSocketIO {
    constructor() {
        this.client = new client_socket();
        this.socketIOStatus = PLVSocketIOStatus.IDLE;
    }
    set_open_listener(g9) {
        this.client.set_open_listener(g9);
    }
    set_fail_listener(f9) {
        this.client.set_fail_listener(f9);
    }
    set_reconnecting_listener(e9) {
        this.client.set_reconnecting_listener(e9);
    }
    set_reconnect_listener(d9) {
        this.client.set_reconnect_listener(d9);
    }
    set_close_listener(c9) {
        this.client.set_close_listener(c9);
    }
    set_socket_open_listener(b9) {
        this.client.set_socket_open_listener(b9);
    }
    set_socket_close_listener(a9) {
        this.client.set_socket_close_listener(a9);
    }
    connect(uri) {
        this.connectWithQuery(uri, '', '');
    }
    connectWithQuery(uri, query, v8) {
        if (this.socketIOStatus == PLVSocketIOStatus.IDLE || this.socketIOStatus == PLVSocketIOStatus.SOCKET_CLOSE) {
            this.socketIOStatus = PLVSocketIOStatus.CONNECT;
            this.onSocketIOStatusListener?.(this.socketIOStatus);
        }
        this.set_open_listener(() => {
            PLVLogger.info(TAG, 'call socket open');
            this.socketIOStatus = this.socketIOStatus == PLVSocketIOStatus.RECONNECT ? PLVSocketIOStatus.RECONNECT_SUCCESS : PLVSocketIOStatus.OPEN;
            this.onSocketIOStatusListener?.(this.socketIOStatus);
        });
        this.set_reconnect_listener(() => {
            PLVLogger.info(TAG, 'call socket reconnect');
            this.socketIOStatus = PLVSocketIOStatus.RECONNECT;
            this.onSocketIOStatusListener?.(this.socketIOStatus);
        });
        this.set_socket_close_listener(() => {
            PLVLogger.info(TAG, 'call socket close');
            this.socketIOStatus = PLVSocketIOStatus.SOCKET_CLOSE;
            this.onSocketIOStatusListener?.(this.socketIOStatus);
        });
        this.set_close_listener(() => {
            PLVLogger.info(TAG, 'call close');
        });
        this.client.connectWithQuery(uri, query, v8);
    }
    connected() {
        return this.opened() && this.socketIOStatus != PLVSocketIOStatus.SOCKET_CLOSE;
    }
    disconnect(u8) {
        if (this.socketIOStatus != PLVSocketIOStatus.SOCKET_CLOSE && !u8) {
            this.socket_close();
        }
        this.close();
    }
    destroy(t8) {
        this.disconnect(t8);
        this.clear_con_listeners();
        this.clear_socket_listeners();
    }
    clear_con_listeners() {
        this.client.clear_con_listeners();
    }
    clear_socket_listeners() {
        this.client.clear_socket_listeners();
    }
    set_reconnect_attempts(s8) {
        this.client.set_reconnect_attempts(s8);
    }
    set_reconnect_delay(r8) {
        this.client.set_reconnect_delay(r8);
    }
    set_reconnect_delay_max(q8) {
        this.client.set_reconnect_delay_max(q8);
    }
    set_logs_default() {
        this.client.set_logs_default();
    }
    set_logs_quiet() {
        this.client.set_logs_quiet();
    }
    set_logs_verbose() {
        this.client.set_logs_verbose();
    }
    close() {
        this.client.close();
    }
    sync_close() {
        this.client.sync_close();
    }
    set_proxy_basic_auth(uri, username, password) {
        this.client.set_proxy_basic_auth(uri, username, password);
    }
    opened() {
        return this.client.opened();
    }
    get_sessionid() {
        return this.client.get_sessionid();
    }
    set_nsp(p8) {
        this.client.set_nsp(p8);
    }
    on(m8, n8) {
        this.client.on(m8, (json) => {
            n8(this.replaceJson(json));
        });
    }
    once(k8, l8) {
        this.client.once(k8, l8);
    }
    off(j8) {
        this.client.off(j8);
    }
    off_all() {
        this.client.off_all();
    }
    socket_close() {
        this.client.socket_close();
    }
    on_error(i8) {
        this.client.on_error(i8);
    }
    off_error() {
        this.client.off_error();
    }
    emitSkipCheck(name, message, g8) {
        this.client.emit(name, message, (json) => {
            g8?.(this.replaceJson(json));
        });
    }
    emit(name, message, e8) {
        PLVLogger.info(TAG, `emit: ${message}, name: ${name}, connected: ${this.connected()}`);
        if (this.connected()) {
            this.client.emit(name, message, (json) => {
                e8?.(this.replaceJson(json));
            });
            return true;
        }
        return false;
    }
    replaceJson(json) {
        return json.replace(/"{/g, '{').replace(/}"/g, '}');
    }
}
export var PLVSocketIOStatus;
(function (d8) {
    d8[d8["IDLE"] = 0] = "IDLE";
    d8[d8["CONNECT"] = 1] = "CONNECT";
    d8[d8["OPEN"] = 2] = "OPEN";
    d8[d8["RECONNECT"] = 3] = "RECONNECT";
    d8[d8["RECONNECT_SUCCESS"] = 4] = "RECONNECT_SUCCESS";
    d8[d8["SOCKET_CLOSE"] = 5] = "SOCKET_CLOSE";
})(PLVSocketIOStatus || (PLVSocketIOStatus = {}));
