if (!("finalizeConstruction" in ViewPU.prototype)) {
    Reflect.set(ViewPU.prototype, "finalizeConstruction", () => {
    });
}
import PLVCommonConstants from '../../common/PLVCommonConstants';
import { PLVFullScreenStatus, PLVWebpageStatus } from '../../common/PLVCommonEnums';
import PLVLogger from '../log/PLVLogger';
import { PLVFailureLayout } from './PLVFailureLayout';
import { PLVLoadingLayout } from './PLVLoadingLayout';
import { PLVNewWindowLayout } from './PLVNewWindowLayout';
import { PLVWebController } from './PLVWebController';
export const TAG = "[PLVSimpleWeb]";
export class PLVSimpleWeb extends ViewPU {
    constructor(parent, params, __localStorage, elmtId = -1, paramsLambda = undefined, extraInfo) {
        super(parent, __localStorage, elmtId, extraInfo);
        if (typeof paramsLambda === "function") {
            this.paramsGenerator_ = paramsLambda;
        }
        this.a2 = new ObservedPropertySimplePU(PLVWebpageStatus.INIT, this, "webStatus");
        this.controller = new PLVWebController();
        this.src = undefined;
        this.incognitoMode = undefined;
        this.showLoading = undefined;
        this.setInitiallyProvidedValue(params);
        this.finalizeConstruction();
    }
    setInitiallyProvidedValue(params) {
        if (params.webStatus !== undefined) {
            this.webStatus = params.webStatus;
        }
        if (params.controller !== undefined) {
            this.controller = params.controller;
        }
        if (params.src !== undefined) {
            this.src = params.src;
        }
        if (params.incognitoMode !== undefined) {
            this.incognitoMode = params.incognitoMode;
        }
        if (params.showLoading !== undefined) {
            this.showLoading = params.showLoading;
        }
    }
    updateStateVars(params) {
    }
    purgeVariableDependenciesOnElmtId(rmElmtId) {
        this.a2.purgeDependencyOnElmtId(rmElmtId);
    }
    aboutToBeDeleted() {
        this.a2.aboutToBeDeleted();
        SubscriberManager.Get().delete(this.id__());
        this.aboutToBeDeletedInternal();
    }
    get webStatus() {
        return this.a2.get();
    }
    set webStatus(newValue) {
        this.a2.set(newValue);
    }
    aboutToAppear() {
        PLVLogger.info(TAG, `load url: ${this.src}`);
    }
    initialRender() {
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Stack.create();
            Stack.width(PLVCommonConstants.FULL_PERCENT);
            Stack.height(PLVCommonConstants.FULL_PERCENT);
        }, Stack);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Web.create({
                controller: this.controller,
                src: this.src,
                incognitoMode: this.incognitoMode
            });
            Web.darkMode(this.controller._darkMode);
            Web.forceDarkAccess(this.controller._forceDarkAccess);
            Web.domStorageAccess(this.controller._domStorageAccess);
            Web.zoomAccess(this.controller._zoomAccess);
            Web.fileAccess(this.controller._fileAccess);
            Web.multiWindowAccess(this.controller._multiWindowAccess);
            Web.allowWindowOpenMethod(this.controller._allowWindowOpenMethod);
            Web.javaScriptAccess(this.controller._javaScriptAccess);
            Web.mixedMode(this.controller._mixedMode);
            Web.cacheMode(this.controller._cacheMode);
            Web.backgroundColor(this.controller._backgroundColor);
            Web.verticalScrollBarAccess(this.controller._verticalScrollBarAccess);
            Web.nestedScroll(this.controller._nestedScrollOptions);
            Web.overScrollMode(this.controller._overScrollMode);
            Web.onControllerAttached(() => {
                PLVLogger.info(TAG, "onControllerAttached: " + this.src);
                this.controller.handleControllerAttached();
                this.controller._onControllerAttached?.();
            });
            Web.onInterceptRequest((event) => {
                if (this.controller._onInterceptRequest) {
                    return this.controller._onInterceptRequest?.(event.request);
                }
                return null;
            });
            Web.onLoadIntercept((event) => {
                let result = false;
                if (this.controller._onLoadIntercept) {
                    result = this.controller._onLoadIntercept?.(event.data);
                }
                result = result || this.controller.handleIsLoadIntercept(event.data);
                return result;
            });
            Web.onWindowNew((event) => {
                if (this.controller._onWindowNew?.(event)) {
                    return;
                }
                this.controller.handleWindowNew(event, (z10) => {
                    return new CustomDialogController({
                        builder: () => {
                            let jsDialog = new PLVNewWindowLayout(this, { webviewController: z10 }, undefined, -1, () => {
                            }, { page: "foundation/src/main/ets/modules/web/PLVSimpleWeb.ets", line: 72, b2: 24 });
                            jsDialog.setController();
                            ViewPU.create(jsDialog);
                            let paramsLambda = () => {
                                return {
                                    webviewController: z10
                                };
                            };
                            jsDialog.paramsGenerator_ = paramsLambda;
                        },
                        cornerRadius: 0
                    }, this);
                });
            });
            Web.onShowFileSelector((event) => {
                if (this.controller._onShowFileSelector) {
                    return this.controller._onShowFileSelector?.(event);
                }
                return true;
            });
            Web.onFullScreenExit(() => {
                PLVLogger.info(TAG, 'onFullScreenExit');
                this.controller._fullScreenStatus = PLVFullScreenStatus.EXIT;
                if (this.controller._onFullScreenExit?.()) {
                    return;
                }
                this.controller.handleFullScreenExit();
            });
            Web.onFullScreenEnter(() => {
                PLVLogger.info(TAG, 'onFullScreenEnter');
                this.controller._fullScreenStatus = PLVFullScreenStatus.ENTER;
                if (this.controller._onFullScreenEnter?.()) {
                    return;
                }
                this.controller.handleFullScreenEnter();
            });
            Web.onProgressChange((event) => {
                PLVLogger.info(TAG, 'onProgressChange:' + event?.newProgress);
                this.controller._onProgressChange?.(event);
            });
            Web.onPageBegin((event) => {
                PLVLogger.info(TAG, 'onPageBegin');
                this.controller._onPageBegin?.(event);
            });
            Web.onErrorReceive((event) => {
                PLVLogger.info(TAG, "onErrorReceive:" + `{info:${event?.error.getErrorInfo()},code:${event?.error.getErrorCode()}}`);
                this.controller.handleErrorReceive();
                this.webStatus = PLVWebpageStatus.FINISHED;
                this.controller._onErrorReceive?.(event);
            });
            Web.onPageEnd((event) => {
                PLVLogger.info(TAG, 'onPageEnd');
                this.controller.handlePageEnd(event);
                if (this.webStatus != PLVWebpageStatus.ERROR) {
                    this.webStatus = PLVWebpageStatus.FINISHED;
                    this.controller._onPageEnd?.(event);
                }
            });
        }, Web);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            If.create();
            if (this.webStatus === PLVWebpageStatus.INIT && this.showLoading) {
                this.ifElseBranchUpdateFunction(0, () => {
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Column.create();
                        Column.backgroundColor(Color.White);
                    }, Column);
                    {
                        this.observeComponentCreation2((elmtId, isInitialRender) => {
                            if (isInitialRender) {
                                let componentCall = new PLVLoadingLayout(this, {}, undefined, elmtId, () => {
                                }, { page: "foundation/src/main/ets/modules/web/PLVSimpleWeb.ets", line: 124, b2: 11 });
                                ViewPU.create(componentCall);
                                let paramsLambda = () => {
                                    return {};
                                };
                                componentCall.paramsGenerator_ = paramsLambda;
                            }
                            else {
                                this.updateStateVarsOfChildByElmtId(elmtId, {});
                            }
                        }, { name: "PLVLoadingLayout" });
                    }
                    Column.pop();
                });
            }
            else {
                this.ifElseBranchUpdateFunction(1, () => {
                });
            }
        }, If);
        If.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            If.create();
            if (this.webStatus === PLVWebpageStatus.ERROR && this.showLoading) {
                this.ifElseBranchUpdateFunction(0, () => {
                    this.observeComponentCreation2((elmtId, isInitialRender) => {
                        Column.create();
                        Column.justifyContent(FlexAlign.Center);
                        Column.alignItems(HorizontalAlign.Center);
                        Column.backgroundColor(Color.White);
                        Column.width(PLVCommonConstants.FULL_PERCENT);
                        Column.height(PLVCommonConstants.FULL_PERCENT);
                    }, Column);
                    {
                        this.observeComponentCreation2((elmtId, isInitialRender) => {
                            if (isInitialRender) {
                                let componentCall = new PLVFailureLayout(this, {
                                    handleReload: () => {
                                        this.webStatus = PLVWebpageStatus.INIT;
                                        this.controller?.refresh();
                                    }
                                }, undefined, elmtId, () => {
                                }, { page: "foundation/src/main/ets/modules/web/PLVSimpleWeb.ets", line: 131, b2: 11 });
                                ViewPU.create(componentCall);
                                let paramsLambda = () => {
                                    return {
                                        handleReload: () => {
                                            this.webStatus = PLVWebpageStatus.INIT;
                                            this.controller?.refresh();
                                        }
                                    };
                                };
                                componentCall.paramsGenerator_ = paramsLambda;
                            }
                            else {
                                this.updateStateVarsOfChildByElmtId(elmtId, {});
                            }
                        }, { name: "PLVFailureLayout" });
                    }
                    Column.pop();
                });
            }
            else {
                this.ifElseBranchUpdateFunction(1, () => {
                });
            }
        }, If);
        If.pop();
        Stack.pop();
    }
    rerender() {
        this.updateDirtyElements();
    }
}
