import webview from "@ohos.web.webview";
import { PLVJsBridge } from 'jsbridge';
import { PLVFullScreenStatus, PLVWebpageStatus } from '../../common/PLVCommonEnums';
import PLVUtils from '../../common/PLVUtils';
import PLVLogger from '../log/PLVLogger';
const d11 = 100;
const TAG = "[PLVWebController]";
export class PLVWebController extends webview.WebviewController {
    constructor(webTag) {
        super(webTag || 'PLVWeb');
        this._webStatus = PLVWebpageStatus.INIT;
        this._fullScreenStatus = PLVFullScreenStatus.IDLE;
        this._originalIsLayoutFullScreen = false;
        this._originalIsFullScreen = false;
        this._addOnReloaded = [];
        this._darkMode = WebDarkMode.Auto;
        this._forceDarkAccess = false;
        this._domStorageAccess = true;
        this._zoomAccess = true;
        this._fileAccess = true;
        this._multiWindowAccess = true;
        this._allowWindowOpenMethod = true;
        this._javaScriptAccess = true;
        this._mixedMode = MixedMode.All;
        this._cacheMode = CacheMode.None;
        this._addOnControllerAttached = [];
        this._addOnPageEnd = [];
        this._backgroundColor = Color.Transparent;
        this._verticalScrollBarAccess = false;
        this._nestedScrollOptions = { scrollForward: NestedScrollMode.SELF_FIRST, scrollBackward: NestedScrollMode.SELF_FIRST };
        this._overScrollMode = OverScrollMode.NEVER;
        this.dialogController = null;
        this.jsBridge = new PLVJsBridge(this);
    }
    accessBackward() {
        if (this._accessBackward?.()) {
            return true;
        }
        else if (this._fullScreenStatus === PLVFullScreenStatus.ENTER) {
            return true;
        }
        try {
            return super.accessBackward();
        }
        catch (e) {
            return false;
        }
    }
    backward() {
        if (this._backward?.()) {
            return;
        }
        if (this._fullScreenStatus === PLVFullScreenStatus.ENTER) {
            this._fullScreenStatus = PLVFullScreenStatus.EXIT;
            this.runJavaScript(PLVUtils.getExitFullScreenJS(true));
        }
        else {
            super.backward();
        }
    }
    darkMode(darkMode) {
        this._darkMode = darkMode;
        return this;
    }
    forceDarkAccess(forceDarkAccess) {
        this._forceDarkAccess = forceDarkAccess;
        return this;
    }
    domStorageAccess(domStorageAccess) {
        this._domStorageAccess = domStorageAccess;
        return this;
    }
    zoomAccess(zoomAccess) {
        this._zoomAccess = zoomAccess;
        return this;
    }
    fileAccess(fileAccess) {
        this._fileAccess = fileAccess;
        return this;
    }
    multiWindowAccess(multiWindowAccess) {
        this._multiWindowAccess = multiWindowAccess;
        return this;
    }
    allowWindowOpenMethod(allowWindowOpenMethod) {
        this._allowWindowOpenMethod = allowWindowOpenMethod;
        return this;
    }
    javaScriptAccess(javaScriptAccess) {
        this._javaScriptAccess = javaScriptAccess;
        return this;
    }
    onControllerAttached(callback) {
        this._onControllerAttached = callback;
        return this;
    }
    addOnControllerAttached(callback) {
        this._addOnControllerAttached.push(callback);
        return this;
    }
    onInterceptRequest(callback) {
        this._onInterceptRequest = callback;
        return this;
    }
    onLoadIntercept(callback) {
        this._onLoadIntercept = callback;
        return this;
    }
    onWindowNew(callback) {
        this._onWindowNew = callback;
        return this;
    }
    onShowFileSelector(callback) {
        this._onShowFileSelector = callback;
        return this;
    }
    onFullScreenEnter(callback) {
        this._onFullScreenEnter = callback;
        return this;
    }
    onFullScreenExit(callback) {
        this._onFullScreenExit = callback;
        return this;
    }
    onProgressChange(callback) {
        this._onProgressChange = callback;
        return this;
    }
    onPageBegin(callback) {
        this._onPageBegin = callback;
        return this;
    }
    onPageEnd(callback) {
        this._onPageEnd = callback;
        return this;
    }
    addOnPageEnd(callback) {
        this._addOnPageEnd.push(callback);
        return this;
    }
    onErrorReceive(callback) {
        this._onErrorReceive = callback;
        return this;
    }
    backgroundColor(backgroundColor) {
        this._backgroundColor = backgroundColor;
        return this;
    }
    verticalScrollBarAccess(verticalScrollBarAccess) {
        this._verticalScrollBarAccess = verticalScrollBarAccess;
        return this;
    }
    nestedScrollOptions(w11) {
        this._nestedScrollOptions = w11;
        return this;
    }
    overScrollMode(overScrollMode) {
        this._overScrollMode = overScrollMode;
    }
    userAgent(userAgent) {
        this._userAgent = userAgent;
        return this;
    }
    addOnReloaded(callback) {
        this._addOnReloaded.push(callback);
        return this;
    }
    registerHandler(v11, handle) {
        this.jsBridge.registerHandler(v11, handle);
        return this;
    }
    callHandle(t11, data, u11) {
        this.jsBridge.callHandle(t11, data, u11);
        return this;
    }
    loadHtmlData(data) {
        PLVLogger.info(TAG, `loadHtmlData: ${data}`);
        try {
            super.loadData(data, "text/html", "UTF-8", ' ', ' ');
        }
        catch (err) {
            const e = err;
            PLVLogger.printError(TAG, `webController loadHtmlData err ${e.code}`, e);
        }
        return this;
    }
    loadUrlCatch(url) {
        PLVLogger.info(TAG, `loadUrlCatch: ${url}`);
        try {
            super.loadUrl(url);
            this._addOnReloaded.forEach((value) => {
                value();
            });
        }
        catch (err) {
            const e = err;
            PLVLogger.printError(TAG, `webController loadUrlCatch err ${e.code}`, e);
        }
    }
    handleControllerAttached() {
        this._addOnControllerAttached.forEach((value) => {
            value();
        });
        if (this._userAgent) {
            this.setCustomUserAgent(this._userAgent);
        }
    }
    handleFullScreenExit() {
        if (PLVUtils.isLandscape()) {
            PLVUtils.changeOrientation(false);
            PLVUtils.setWindowFullScreen(this._originalIsLayoutFullScreen, this._originalIsFullScreen);
        }
    }
    handleFullScreenEnter() {
        this.getVideoWHEnterFullScreen(d11, d11, d11 * 10);
    }
    handleWindowNew(event, builder) {
        if (this.dialogController) {
            this.dialogController.close();
        }
        let q11 = new webview.WebviewController();
        this.dialogController = builder(q11);
        this.dialogController.open();
        event.handler.setWebController(q11);
    }
    handleIsLoadIntercept(intercept) {
        try {
            return this.jsBridge.isInterceptRequest(intercept);
        }
        catch (e) {
            PLVLogger.info(TAG, 'IsLoadIntercept catch');
            return false;
        }
    }
    handlePageEnd(event) {
        this._addOnPageEnd.forEach((value) => {
            value(event);
        });
        this._webStatus = PLVWebpageStatus.FINISHED;
        PLVUtils.retryWhen(() => {
            this.jsBridge.loadLocalJs(PLVWebController.importSDKModuleContext);
        }, () => {
            this.jsBridge.loadLocalJs(getContext(this));
        })
            .then(() => {
            PLVLogger.info(TAG, 'LoadLocalJs success');
        })
            .catch((err) => {
            PLVLogger.info(TAG, `LoadLocalJs catch\n${err.stack}`);
        });
    }
    handleErrorReceive() {
        this._webStatus = PLVWebpageStatus.FINISHED;
    }
    getVideoWHEnterFullScreen(delayTime, e11, f11) {
        if (delayTime > f11) {
            return;
        }
        setTimeout(() => {
            this.runJavaScript(PLVUtils.getVideoRectJS(true)).then((value) => {
                let i11 = JSON.parse(value);
                if (i11.width === 0 && i11.height === 0) {
                    this.getVideoWHEnterFullScreen(delayTime + e11, e11, f11);
                }
                else if (i11.width > i11.height) {
                    PLVUtils.changeOrientation(true);
                    PLVUtils.setWindowFullScreen(true, true).then((k11) => {
                        this._originalIsLayoutFullScreen = k11[0];
                        this._originalIsFullScreen = k11[1];
                    });
                }
            });
        }, delayTime);
    }
}
